C LAST UPDATE: 
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C**************************
C**     LDM_GET_DGEOM    **
C**************************
C
C
CD-Doc:
C DGEOm            SUBROUTINE LDM_GET_DGEOM (VALSTR, IVAL, IFLAG)
CD-end
      SUBROUTINE LDM_GET_DGEOM (VALSTR, IVAL, IFLAG)
C
      INCLUDE 'implicit_none.finc'
C
C Purpose: Get value of string/code parameter IMAGE_DATA
C
C Author:  John W. Campbell, July 1994
C
C Arguments:
C
      CHARACTER*(*) VALSTR
      INTEGER IVAL
      INTEGER IFLAG

C  VALSTR    (W)   Value for the parameter as a string 'flat' or 'cyl' 
C  IVAL      (W)   Code number 1=flat, 2=cyl
C  IFLAG     (W)   Flag = -1 undefined value
C                       =  0 default value
C                       =  1 value set explicitly
C                       =  2 value set globally
C
C====== GLOBALS:
C
      INCLUDE 'ldm_data.finc'
      EXTERNAL LDM_BDAT
C
C====== LOCALS:
C
      CHARACTER*4 STR(2)

      DATA STR/'flat','cyl'/
C
C-------------------------------------------------------------------------------
C
      IVAL = DGEOM
      VALSTR = STR(IVAL)
      IFLAG = IS_DGEOM
      RETURN
      END
